#!/usr/bin/env python
# encoding: utf-8

import sys
from functools import wraps
from Naked.toolshed.types import NakedObject, XList

def print_scratch(func):
    @wraps(func)
    def print_wrapper(*args, **kwargs):
        print(func(*args, **kwargs))
    return print_wrapper


def run_scratchpad():
    # from Naked.toolshed.file import FileReader
    # from Naked.toolshed.types import XString, XUnicode

    # r = FileReader('/Users/ces/Desktop/code/naked/tests/testfiles/unicode.txt')
    # test1 = r.read_utf8()
    # test2 = XUnicode(test1, {'a': 'b'})
    # test3 = "Hey! It's Bengali ব য,and here is some more ২"
    # print(unicode(test2))

    def true_a(xlist_item):
            return xlist_item.startswith('a')

    def cap_val(xlist_item):
        return xlist_item.upper()

    xl = XList(['one', 'two', 'three'], {'type': 'orderlist'})
    print(xl.multi_wildcard_match('o*|*hre*')) # prints ['one', 'three']


if __name__ == '__main__':
    run_scratchpad()
